# Nmapthon2

The evolution of [Nmapthon](https://github.com/cblopez/nmapthon), an Nmap automation module for humans.

**What can I do with Nmapthon2?**

- **Perform Nmap scans**: Easily customize your options, execute raw scans, parse an Nmap file or resume scans.
- Retrieve all the **results** with a few lines of code, including:
  - Overall scan information
  - Hosts, ports and services.
  - Operating systems and OS matches
  - Host and port scripts
  - Traceroute information
  - And more!
- **Extend the NSE** (Nmap Scripting Engine) with your own **Python code**.
- Perform **asynchronous scans** and control your main thread.
- View **scan status**.
- Use several Nmap-based **utilities**

### Installation

Make sure you have Python 3.5+ and [Nmap](https://nmap.org) installed on your system. Then run:

```
pip3 install nmapthon2

# Or
pip install nmapthon2
```

This library is **cross-platform**.

### Documentation

Full documentation inside ReadTheDocs, over [here](https://readthedocs.com).

### Disclaimer

Hope you all enjoy this module. Please, do not try its features without the consent of your targets. It is recommended to use your own virtual lab.
